import os
import sys
import ctypes


def test_01():
    print("test_01")
    print(os.getcwd())
    print(sys.path)

def test_02():
    # 获取当前py文件路径
    current_path = os.path.dirname(os.path.abspath(__file__))
    print(current_path, "3")
    # 切换到当前路径
    dll_path = os.path.join(current_path, r'.\include\VnHardwareConf.dll')

    HdConfigLib = ctypes.CDLL(dll_path)
    HdConfigLib.getVersion.restype = ctypes.c_char_p
    result = HdConfigLib.getVersion()
    print(f"Result: {result.decode('utf-8')}")


if __name__ == '__main__':
    test_01()
    test_02()



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="proname",
    version="1.0.11",
    author="ZZL",
    url='https://www.baidu.com',
    author_email="test01@163.com",
    description="first test package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
    include_package_data=True,
    data_files=[('include', ['src/proname/include/VnHardwareConf.dll'])],
)